@@ -7,7 +7,7 @@ import torch
 from transformers import AutoConfig, AutoTokenizer, AutoModelForTokenClassification
 from transformers import pipeline
 from transformers.utils import logging
-
+from nlpaf import logger
 import pandas as pd
 from nlpaf.util.timer import Timer
 # REQUIRES sentencizer
@@ -48,15 +48,17 @@ class EmotionHartmannFactory:
             all_scores[em] = []
 
         sentence_lbls = []
-
+        logger.debug("In the emotion pipe")
         #outer = Timer(name="one text")
         #outer.start()
         for sentence in doc.sents:
             txt = sentence.text
+            logger.debug("In the emotion pipe- looping over sentences")
             #print(f"printing sent: {txt}")
             #t = Timer(name="one-sentence")
             #t.start()
             sent_emotion_result = self.transformer_nlp(txt)
+            logger.debug(f"sent_emotion_result {sent_emotion_result}")
             #t.stop()
             #t.start()
             res_df = pd.DataFrame(sent_emotion_result)
@@ -70,6 +72,7 @@ class EmotionHartmannFactory:
                 sentence._.set(f"emotion_{label}", score)
             dominant_lbl = res_df.iloc[res_df["score"].argmax()]["label"]
             sentence._.set(f"emotion_dominant", dominant_lbl)
+            logger.debug(f"appending")
             sentence_lbls.append(dominant_lbl)
             #t.stop()
         #outer.stop()
@@ -89,7 +92,7 @@ class EmotionHartmannFactory:
             }
             for x in set(sentence_lbls)
         ]).set_index("label")
-
+        logger.debug(f"setting prediction")
         predictions_df = doc_scores_df.merge(doc_mean_df,
                                           how='outer',
                                           left_index=True,
@@ -97,5 +100,6 @@ class EmotionHartmannFactory:
 
         doc._.set("emotions", predictions_df.reset_index().to_dict('records'))
         doc._.set("emotion_label", predictions_df.reset_index().iloc[predictions_df["count"].argmax()]["label"])
+        logger.debug("1 emotion call done")
         #all_.stop()
         return doc
\ No newline at end of file
