@@ -7,6 +7,7 @@ from transformers.utils import logging
 from transformers import pipeline
 from transformers import RobertaTokenizer, RobertaForSequenceClassification
 from nlpaf.util.timer import Timer
+from nlpaf import logger
 
 # REQUIRES sentencizer
 #https://huggingface.co/SkolkovoInstitute/roberta_toxicity_classifier?text=I+like+you.+I+love+you
@@ -45,7 +46,7 @@ class ToxicityFactory:
         all_scores["toxic"] = []
 
         sentence_lbls = []
-
+        logger.debug("in toxic")
         for sentence in doc.sents:
             txt = sentence.text
             sent_toxicity_result = self.transformer_nlp(txt)
@@ -87,4 +88,5 @@ class ToxicityFactory:
 
         doc._.set("toxicity", predictions)
         #t.stop()
+        logger.debug("in toxic - 1 run done")
         return doc
\ No newline at end of file
